import gdata.service
import gdata.blogger.service as gblogger

blogs = []

def create_blogger_client(user, password):
    """Creates a GDataService and provides ClientLogin auth details to it.
    """
    # Authenticate using ClientLogin.
    service = gdata.service.GDataService(user, password)
    service.source = 'Maemo WordPy'
    service.service = 'blogger'
    service.server = 'www.blogger.com'
    service.ProgrammaticLogin()

    return service

def get_blog_list(bgclient):
    del blogs[:]

    feed = bgclient.Get('/feeds/default/blogs')

    for i in range(len(feed.entry)):
        blogs.append([feed.entry[i].title.text, feed.entry[i].id.text.split('-')[-1]])

    return blogs

def get_posts_with_status(user, password, blogid, numposts):
    bgclient = create_blogger_client(user, password)
    # Request the feed.
    feed = bgclient.GetFeed('/feeds/' + blogid + '/posts/default?max-results=' +\
                            str(numposts))
    posts = []
    for entry in feed.entry:
        title = entry.title.text
        url = entry.GetEditLink().href
        if entry.control is not None:
            status = 'draft'
        else:
            status = 'publish'
        post = [title, url, status]
        posts.append(post)

    return posts

def encode_technorati_tags(content_text):
    import re
    techno_tags = []
    hele = re.compile(r'"http://technorati.com/tag/[^$%]+"')
    a = hele.findall(content_text)
    b = a[0].split('"')
    for j in range(len(b)):
        if b[j].find("http://technorati.com/tag/") >=0:
            c = b[j].replace('http://technorati.com/tag/', '')
            techno_tags.append(c)

    tech_tags_entries = (', ').join(techno_tags)

    if content_text.find("<small>Technorati Tags:") >= 0:
        descr = content_text.partition('<br /><br /><p style="text-align: right"><small>Technorati Tags:')
    else:
        descr = content_text.partition('<br /><br /><p style="text-align:right;">Technorati Tags:')

    return descr[0], tech_tags_entries

def get_post_filtered(user, password, postid, blogid):
    bgclient = create_blogger_client(user, password)
    feed = bgclient.GetFeed('/feeds/%s/posts/default' % blogid)
    
    title = ''
    content = ''
    extended = ''
    excerpt = ''
    ttags = ''
    tracks = ''
    cats = ''
    slug = ''
    pssword = ''
    comments = ''
    pings = ''
    postid = postid
    
    label_list = []
    for entry in feed.entry:
        if entry.GetEditLink().href == postid:
            if entry.title.text is not None:
                title = entry.title.text
            if entry.content.text is not None:
                if entry.content.text.find("Technorati Tags:") >= 0:               
                    content, ttags = encode_technorati_tags(entry.content.text)
                else:
                    content = entry.content.text
                    
            #date=2008-09-15T11:11:00.001-07:00
            postdate = entry.published.text
            year, month, day = postdate.split('T')[0].split('-')
            hour = postdate.split('T')[1].split(':')[0]
            minutes = postdate.split('T')[1].split(':')[1]            
            date = [year, month, day, hour, minutes]
            
            for i in entry.category:
                label_list.append(i.term)
            tags = (', ').join(label_list)
            if entry.control is not None:
                status = 'draft'
            else:
                status = 'publish'

    return (title, content, extended, excerpt, ttags, tracks, tags, cats, date, \
            slug, pssword, comments, pings, status, postid)
